@@ -20,9 +20,10 @@ import numpy as np
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 
-from satis import (get_average_psd, ROUND_PRECISION, define_good_time_array, interpolate_signals,
-                       define_good_time_array, get_cumulative_average, add_credits, tight_plot, get_coeff_fourier,
+from satis.satis_library import (get_average_psd, ROUND_PRECISION, define_good_time_array, interpolate_signals,
+                       define_good_time_array, get_cumulative_average, get_coeff_fourier,
                        get_clean_fft, compute_cumulative_fourier, get_psd_harmonics)
+from satis.cerfacs_plot import add_credits, tight_plot
 
 import pandas as pd
 
@@ -455,9 +456,9 @@ def plot_time_signals(time, signals, target_frequency, transient_time, unit):
     # Show
     add_credits(figure)
     tight_plot(figure)
-    plt.show()
+    #plt.show()
 
-    return
+    return figure
 
 
 def plot_fourier_convergence(time, signals, target_frequency, transient_time, unit):
@@ -649,8 +650,7 @@ def plot_fourier_convergence(time, signals, target_frequency, transient_time, un
     add_credits(figure)
     tight_plot(figure)
 
-    plt.show()
-    return
+    return figure
 
 
 def plot_psd_convergence(time, signals, target_frequency,
@@ -869,9 +869,8 @@ def plot_psd_convergence(time, signals, target_frequency,
 
     add_credits(figure)
     tight_plot(figure)
-    plt.show()
 
-    return
+    return figure
 
 
 def plot_fourier_variability(time, signals, target_frequency, transient_time, unit):
@@ -1050,9 +1049,8 @@ def plot_fourier_variability(time, signals, target_frequency, transient_time, un
 
     add_credits(figure)
     tight_plot(figure)
-    plt.show()
 
-    return
+    return figure
 
 
 def plot_psd_variability(time, signals, target_frequency, transient_time,
@@ -1156,8 +1154,8 @@ def plot_psd_variability(time, signals, target_frequency, transient_time,
 
     add_credits(figure)
     tight_plot(figure)
-    plt.show()
-    return
+
+    return figure
 
 
 def write_output(time, signals, target_frequency,
