@@ -50,9 +50,9 @@ def calc_autocorrelation_time(time, signal, threshold=0.2):
 						correlation under the threshold
 	"""
 
-    signal -= np.mean(signal)
+    fluctu = signal - np.mean(signal)
     time -= time[0]
-    correlation = np.correlate(signal, signal, "full")
+    correlation = np.correlate(fluctu, fluctu, "full")
     correlation = abs(correlation[int((correlation.size - 1) / 2) :])
     correlation /= correlation[0]
     # 1-D interpol on correlation
